# Movable Type plugin.
#
# Release 0.01 (Feb 22, 2009) initial version.
# Release 0.02 (Mar 28, 2009) add email and website-url control.
# Release 0.03 (Apr 05, 2009) fixed bug.
#
# Copyright (c) 2004-2009 Yujiro Araki

package MT::Plugin::UserNameEditController;
use strict;
use base qw(MT::Plugin);

use MT;
use MT::Blog;

our $VERSION = '0.03';

my $plugin = __PACKAGE__->new({
    id => 'UserNameEditController',
    name => 'UserNameEditController',
    description => '<MT_TRANS phrase="UserNameEditController.">',
    doc_link => 'http://www.koikikukan.com/archives/2009/02/23-005555.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    l10n_class => 'UserNameEditController::L10N',
    system_config_template => 'config.tmpl',
    settings => new MT::PluginSettings ([
        ['userNameEditController_display_name', { Default => 0, Scope => 'system' }],
        ['userNameEditController_email', { Default => 0, Scope => 'system' }],
        ['userNameEditController_website_url', { Default => 0, Scope => 'system' }],
    ]),
    version => $VERSION,
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'MT::App::CMS::template_source.edit_author'
                => \&display_edit_author,
        },
   });
}

sub display_edit_author {
    my ($cb, $app, $template) = @_;

    my $old = <<HERE;
<mtapp:setting
    id="name"
    required="1"
    label="<__trans phrase="Username">"
    hint="<__trans phrase="The username used to login.">">
    <div class="textarea-wrapper">
        <input name="name" id="name" class="full-width" value="<mt:var name="name" escape="html">" <mt:unless name="auth_mode_mt"><mt:unless name="new_user_external_auth">disabled="disabled"</mt:unless></mt:unless> /><mt:unless name="auth_mode_mt"><mt:unless name="new_user_external_auth"><input name="name" type="hidden" value="<mt:var name="name" escape="html">" /></mt:unless></mt:unless>
    </div>
</mtapp:setting>
HERE
    $old = quotemeta($old);

    my $new = <<HERE;
<mt:ignore>
perm_is_superuser:<mt:var name="perm_is_superuser" /><br />
new_object:<mt:var name="new_object" /><br />
editing_other_profile:<mt:var name="editing_other_profile" /><br />
</mt:ignore>
<mt:setvar name="required" value="1">
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
      <mt:setvar name="required" value="0">
    </mt:unless>
  </mt:unless>
</mt:unless>
<mtapp:setting
    id="name"
    required="\$required"
    label="<__trans phrase="Username">"
    hint="<__trans phrase="The username used to login.">">
    <div class="textarea-wrapper"
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
style="padding-left:0;border:none;"
    </mt:unless>
  </mt:unless>
</mt:unless>
>
        <input name="name" id="name" class="full-width" value="<mt:var name="name" escape="html">" 
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
readonly="readonly" style="color:#000;background:#fff"
    </mt:unless>
  </mt:unless>
</mt:unless>
 />
<mt:unless name="new_object">
<input name="name" type="hidden" value="<mt:var name="name" escape="html">" />
</mt:unless>
    </div>
</mtapp:setting>
HERE

    $$template =~ s/$old/$new/;

    if ($plugin->get_config_value('userNameEditController_display_name')) {

        $old = <<HERE;
    <mtapp:setting
        id="nickname"
        required="1"
        label="<__trans phrase="Display Name">"
        hint="<__trans phrase="The name used when published.">">
        <div class="textarea-wrapper">
            <input name="nickname" id="nickname" class="full-width" value="<mt:var name="nickname" escape="html">" />
        </div>
    </mtapp:setting>
HERE
        $old = quotemeta($old);
 
        $new = <<HERE;
    <mtapp:setting
        id="nickname"
        required="\$required"
        label="<__trans phrase="Display Name">"
        hint="<__trans phrase="The name used when published.">">
        <div class="textarea-wrapper"
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
style="padding-left:0;border:none;"
    </mt:unless>
  </mt:unless>
</mt:unless>
>
            <input name="nickname" id="nickname" class="full-width" value="<mt:var name="nickname" escape="html">"
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
readonly="readonly" style="color:#000;background:#fff"
    </mt:unless>
  </mt:unless>
</mt:unless>
 />
        </div>
    </mtapp:setting>
HERE
        $$template =~ s/$old/$new/;
    }

    if ($plugin->get_config_value('userNameEditController_email')) {

        $old = <<HERE;
    <mtapp:setting
        id="email"
        required="\$auth_mode_mt"
        label="<__trans phrase="Email Address">"
        hint="<__trans phrase="The email address associated with this user.">">
        <div class="textarea-wrapper">
            <input name="email" id="email" class="full-width" value="<mt:var name="email" escape="html">" />
        </div>
    </mtapp:setting>
HERE
        $old = quotemeta($old);
 
        $new = <<HERE;
    <mtapp:setting
        id="email"
        required="0"
        label="<__trans phrase="Email Address">"
        hint="<__trans phrase="The email address associated with this user.">">
        <div class="textarea-wrapper"
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
style="padding-left:0;border:none;"
    </mt:unless>
  </mt:unless>
</mt:unless>
>
            <input name="email" id="email" class="full-width" value="<mt:var name="email" escape="html">"
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
readonly="readonly" style="color:#000;background:#fff"
    </mt:unless>
  </mt:unless>
</mt:unless>
 />
        </div>
    </mtapp:setting>
HERE
        $$template =~ s/$old/$new/;
    }

    if ($plugin->get_config_value('userNameEditController_website_url')) {

        $old = <<HERE;
    <mtapp:setting
        id="url"
        label="<__trans phrase="Website URL">"
        hint="<__trans phrase="The URL of the site associated with this user. eg. http://www.movabletype.com/">">
        <div class="textarea-wrapper">
            <input name="url" id="url" class="full-width" value="<mt:var name="url" escape="html">" />
        </div>
    </mtapp:setting>
HERE
        $old = quotemeta($old);
 
        $new = <<HERE;
    <mtapp:setting
        id="url"
        label="<__trans phrase="Website URL">"
        hint="<__trans phrase="The URL of the site associated with this user. eg. http://www.movabletype.com/">">
        <div class="textarea-wrapper"
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
style="padding-left:0;border:none;"
    </mt:unless>
  </mt:unless>
</mt:unless>
>
            <input name="url" id="url" class="full-width" value="<mt:var name="url" escape="html">"
<mt:unless name="new_object">
  <mt:unless name="perm_is_superuser">
    <mt:unless name="editing_other_profile">
readonly="readonly" style="color:#000;background:#fff"
    </mt:unless>
  </mt:unless>
</mt:unless>
 />
        </div>
    </mtapp:setting>
HERE
        $$template =~ s/$old/$new/;
    }
}

1;
